#include <string.h>
#include <stdio.h>
#include "MDR32F9Qx_port.h"
#include "MDR32F9Qx_rst_clk.h"
#include "disp.h"
#include "mcp23s18.h"
#ifdef __MT12864J__
#include "mt12864j_drv.h"
#include "mt12864j_font.h"
#endif
#ifdef __JDT1800__
#include "jdt1800_drv.h"
#endif
#ifdef __HY28B__
#include "hy28b_drv.h"
#include "hy28b_font.h"
#include "system_MDR1986BE4.h"
#endif

//#define __BE1__

static void disp_HardwareInit(void)
{	// CE1, CE2, A0
	PORT_InitTypeDef PORT_InitStructure;

  RST_CLK_PCLKcmd(RST_CLK_PCLK_PORTA, ENABLE);

  PORT_InitStructure.PORT_Pin   = (PORT_Pin_3 | PORT_Pin_4 | PORT_Pin_11);
  PORT_InitStructure.PORT_OE    = PORT_OE_OUT;
	
	PORT_InitStructure.PORT_PULL_UP = PORT_PULL_UP_ON;
	PORT_InitStructure.PORT_PULL_DOWN = PORT_PULL_DOWN_OFF;
  PORT_InitStructure.PORT_FUNC  = PORT_FUNC_PORT;
  PORT_InitStructure.PORT_MODE  = PORT_MODE_DIGITAL;
  PORT_InitStructure.PORT_SPEED = PORT_SPEED_MAXFAST;
  PORT_Init(MDR_PORTA, &PORT_InitStructure); 	
	
}
void LCD_CE0 (unsigned char on_off)
{
	PORT_WriteBit(MDR_PORTA, PORT_Pin_3, on_off ? Bit_SET : Bit_RESET);
}

void LCD_CE1 (unsigned char on_off)
{	
	PORT_WriteBit(MDR_PORTA, PORT_Pin_4, on_off ? Bit_SET : Bit_RESET);
	
}
void LCD_A0 (unsigned char on_off)
{

	PORT_WriteBit(MDR_PORTA, PORT_Pin_11, on_off ? Bit_SET : Bit_RESET);

}
//-----------------------------------------
void disp_Init(void)
{disp_HardwareInit();
#ifdef __MT12864J__
	mt12864j_Init();
#endif
#ifdef __HY28B__
	hy28b_Init();
	hy28b_Clear(White);
#endif
#ifdef __JDT1800__
	jdt1800_Init();	
#endif	
}

//-----------------------------------------
void disp_LedOn(void)
{ 
	#ifdef __BE1__
	PORT_WriteBit(MDR_PORTF, PORT_Pin_14, Bit_SET);	//  
  #else
	mcp23s18_WriteBit(LCD_LED, 1);
	#endif
	
}

//-----------------------------------------
void disp_LedOff(void)
{ 
	#ifdef __BE1__
	PORT_WriteBit(MDR_PORTF, PORT_Pin_14, Bit_RESET);	//  
  #else
	mcp23s18_WriteBit(LCD_LED, 0);
	#endif
	
}

//-----------------------------------------
void disp_ClearFull(void)
{
	#ifdef __MT12864J__
		mt12864j_Clear();
	#endif
	#ifdef __HY28B__
		hy28b_Clear(White);	
	#endif
	#ifdef __JDT1800__	
		jdt1800_ClearFull();		
	#endif		
}

//-----------------------------------------
void disp_ClearRegion(unsigned short x, unsigned short y, unsigned short cx, unsigned short cy)
{
	#ifdef __MT12864J__
		unsigned char row, col;
		for(row = (unsigned char)y; row < (unsigned char)((y + cy) & 0xFF); row++){
			for(col = (unsigned char)x; col < (unsigned char)((x + cx) & 0xFF); col++){
				mt12864j_PrintChar((unsigned char)(row & 0xFF), (unsigned char)((col * 6) & 0xFF), 0x00, 0);	
			}
		}
	#endif
	#ifdef __HY28B__
		unsigned char row, col;		
		for(row = y; row < y + cy; row++){
			for(col = x; col < x + cx; col++){
				hy28b_PrintChar(col, row, ' ', White, White);
			}
		}
	#endif
	#ifdef __JDT1800__		
	jdt1800_ClearRegion((unsigned char)x, (unsigned char)y, (unsigned char)cx, (unsigned char)cy);
	#endif		
}

//-----------------------------------------
void disp_ShowByte(unsigned short x, unsigned short y, unsigned char ch)
{
	#ifdef __MT12864J__
		mt12864j_Byte((unsigned char)(y & 0xFF), (unsigned char)((x) & 0xFF), ch);	
	#endif
	#ifdef __HY28B__	
		hy28b_PrintByteScale(x, y * 8, ch, Black, White);	
	#endif
	#ifdef __JDT1800__
		jdt1800_PrintByte(x, y * 8, ch, WHITE);
	#endif		
}

//-----------------------------------------
void disp_ShowChar(unsigned short x, unsigned short y, unsigned char ch)
{
	#ifdef __MT12864J__		
		mt12864j_PrintChar((unsigned char)(y & 0xFF), (unsigned char)((x * 6) & 0xFF), ch, 0);
	#endif
	#ifdef __HY28B__
	hy28b_PrintChar(x, y, ch, Black, White);
	#endif
	#ifdef __JDT1800__
		jdt1800_PrintLargeChar((unsigned char)x, (unsigned char)y, ch, WHITE);
	#endif		
}

//-----------------------------------------
void disp_ShowCharEx(unsigned short x, unsigned short y, unsigned char ch, unsigned char blink)
{
	#ifdef __MT12864J__		
		mt12864j_PrintChar((unsigned char)(y & 0xFF), (unsigned char)((x * 6) & 0xFF), ch, blink);
	#endif
	#ifdef __HY28B__	
		hy28b_PrintChar(x, y, ch, Black, White);	
	#endif
	#ifdef __JDT1800__
		jdt1800_PrintLargeChar((unsigned char)x, (unsigned char)y, ch, WHITE);
	#endif		
}

//-----------------------------------------
//    
void disp_ShowStr(unsigned short x, unsigned short y, char* str)
{		
	#ifdef __MT12864J__		
		const unsigned char null[] = "                    ";	
		mt12864j_PrintString((unsigned char)(y & 0xFF), (unsigned char)((x * 6) & 0xFF), (unsigned char*)str, 0);		
		if(str && (strlen(str) < disp_XSize()))
			mt12864j_PrintString((unsigned char)(y & 0xFF), (unsigned char)(((x + strlen(str)) * 6) & 0xFF), (unsigned char*)null, 0);		
	#endif
	#ifdef __HY28B__
		unsigned char str_out[MAX_X / HY_FONT_X - 1];	
		
		memset(str_out, ' ', MAX_X / HY_FONT_X - 1);
		memcpy(str_out, str, strlen(str));
		hy28b_PrintString(x, y, (unsigned char*)str_out, Black, White);
	
	#endif
	#ifdef __JDT1800__		
		unsigned char str_out[COL_SIZE / LARGE_FONT_COL - 1];	
		memset(str_out, ' ', COL_SIZE / LARGE_FONT_COL - 1);
		memcpy(str_out, str, strlen(str));
		jdt1800_PrintLargeBuf((unsigned char)x, (unsigned char)y, str_out, COL_SIZE / LARGE_FONT_COL - 1, WHITE);				
	#endif		
}

//-----------------------------------------
//     
unsigned short disp_XSize(void)
{
	#ifdef __MT12864J__
	return MT12864J_XSIZE - 1;
	#endif
	#ifdef __HY28B__		
	return MAX_X / HY_FONT_X - 1;
	#endif
	#ifdef __JDT1800__		
	return COL_SIZE / LARGE_FONT_COL - 1;
	#endif		
}

//-----------------------------------------
//     
unsigned short disp_YSize(void)
{
	#ifdef __MT12864J__	
	return MT12864J_YSIZE - 1;
	#endif
	#ifdef __HY28B__
	return MAX_Y / HY_FONT_Y - 1;
	#endif
	#ifdef __JDT1800__		
	return ROW_SIZE / LARGE_FONT_ROW - 1;	
	#endif		
}

//-----------------------------------------
unsigned short disp_XPixel(void)
{
	#ifdef __MT12864J__
	return (MT12864J_XSIZE - 1) * FONT_WIDTH;
	#endif
	#ifdef __HY28B__		
	return (MAX_X / HY_FONT_X - 1) * HY_FONT_X;
	#endif
	#ifdef __JDT1800__		
	return (COL_SIZE / LARGE_FONT_COL - 1) * LARGE_FONT_COL;
	#endif		
}

//-----------------------------------------
unsigned short disp_YPixel(void)
{
	#ifdef __MT12864J__
	return (MT12864J_YSIZE - 1) * FONT_HEIGHT;
	#endif
	#ifdef __HY28B__		
	return (MAX_Y / HY_FONT_Y - 1) * HY_FONT_Y;
	#endif
	#ifdef __JDT1800__		
	return (ROW_SIZE / LARGE_FONT_ROW - 1) * LARGE_FONT_ROW;	
	#endif		
}

//-----------------------------------------
void disp_CharPosition(int x, int y, int* xch, int* ych)
{
	#ifdef __MT12864J__	
	*xch = x / FONT_WIDTH;
	*ych = y / FONT_HEIGHT;
	#endif
	#ifdef __HY28B__
	*xch = x / HY_FONT_X;
	*ych = y / HY_FONT_Y;
	#endif
	#ifdef __JDT1800__		
	*xch = x / LARGE_FONT_COL;
	*ych = y / LARGE_FONT_ROW;
	#endif			
}
