#include "disp.h"

#ifdef __JDT1800__

#include "MDR32F9Qx_port.h"
#include "MDR32F9Qx_rst_clk.h"
#include "MDR32F9Qx_ssp.h"

#include "itmr.h"
#include "jdt1800_drv.h"
#include "jdt1800_font.h"
#include "mcp23s18.h"

//#define _JDT1800_DEBUG
#ifdef _JDT1800_DEBUG
#include "uart.h"
#endif

#define ROW_SIZE	128
#define COL_SIZE	160

#define LARGE_FONT_ROW	11
#define LARGE_FONT_COL	8

#define SMALL_FONT_ROW	7
#define SMALL_FONT_COL	5

static void jdt1800_HardwareInit(void)
{
	// SPI
	SSP_InitTypeDef sSSP;
	SSP_DeInit(MDR_SSP1);
	SSP_BRGInit(MDR_SSP1,SSP_HCLKdiv2);		//16
	
	SSP_StructInit(&sSSP);

  sSSP.SSP_SCR  = 0x0;  //20
  sSSP.SSP_CPSDVSR = 2;
  sSSP.SSP_Mode = SSP_ModeMaster;
  sSSP.SSP_WordLength = SSP_WordLength8b;
  sSSP.SSP_SPH = SSP_SPH_1Edge;//SSP_SPH_1Edge;
  sSSP.SSP_SPO = SSP_SPO_High;//SSP_SPO_Low;
  sSSP.SSP_FRF = SSP_FRF_SPI_Motorola;
  sSSP.SSP_HardwareFlowControl = SSP_HardwareFlowControl_SSE;
  SSP_Init (MDR_SSP1, &sSSP);
	SSP_DMACmd(MDR_SSP1, (SSP_DMA_TXE | SSP_DMA_RXE), DISABLE);
	
	SSP_Cmd(MDR_SSP1, ENABLE);	
}

// byte -   
// cd - 0 -   1 -  
static void jdt1800_WriteByte(char byte, char cd)
{
	unsigned char bit;
	//   - .
	LCD_CE0(0);
	//   0   1
	cd ?	LCD_A0(1):LCD_A0(0);
	
	SendAndRcvByte(byte);
	//   - .
	LCD_CE0(1);
}

static void jdt1800_Area(unsigned char x0, unsigned char y0, unsigned char x1, unsigned char y1);
static void jdt1800_SetSingleColor(unsigned int color);

void jdt1800_Init(void)
{
	char i;
	
	jdt1800_HardwareInit();
		
  jdt1800_WriteByte(0xB9, 0);//SETEXTC
  jdt1800_WriteByte(0xFF, 1);
  jdt1800_WriteByte(0x83, 1);
  jdt1800_WriteByte(0x53, 1);

  jdt1800_WriteByte(0xB0, 0);//RADJ
  jdt1800_WriteByte(0x3C, 1);
  jdt1800_WriteByte(0x01, 1);

  jdt1800_WriteByte(0xB6, 0);//VCOM
  jdt1800_WriteByte(0x94, 1);
  jdt1800_WriteByte(0x6C, 1);
  jdt1800_WriteByte(0x50, 1);

  jdt1800_WriteByte(0xB1, 0);//PWR
  jdt1800_WriteByte(0x00, 1);
  jdt1800_WriteByte(0x01, 1);
  jdt1800_WriteByte(0x1B, 1);
  jdt1800_WriteByte(0x03, 1);
  jdt1800_WriteByte(0x01, 1);
  jdt1800_WriteByte(0x08, 1);
  jdt1800_WriteByte(0x77, 1);
  jdt1800_WriteByte(0x89, 1);

  jdt1800_WriteByte(0xE0, 0); //Gamma setting for tpo Panel
  jdt1800_WriteByte(0x50, 1);
  jdt1800_WriteByte(0x77, 1);
  jdt1800_WriteByte(0x40, 1);
  jdt1800_WriteByte(0x08, 1);
  jdt1800_WriteByte(0xBF, 1);
  jdt1800_WriteByte(0x00, 1);
  jdt1800_WriteByte(0x03, 1);
  jdt1800_WriteByte(0x0F, 1);
  jdt1800_WriteByte(0x00, 1);
  jdt1800_WriteByte(0x01, 1);
  jdt1800_WriteByte(0x73, 1);
  jdt1800_WriteByte(0x00, 1);
  jdt1800_WriteByte(0x72, 1);
  jdt1800_WriteByte(0x03, 1);
  jdt1800_WriteByte(0xB0, 1);
  jdt1800_WriteByte(0x0F, 1);
  jdt1800_WriteByte(0x08, 1);
  jdt1800_WriteByte(0x00, 1);
  jdt1800_WriteByte(0x0F, 1);

  jdt1800_WriteByte(0x3A, 0);
  jdt1800_WriteByte(0x05, 1);  //05

  jdt1800_WriteByte(0x36, 0);
  jdt1800_WriteByte(0xC0, 1); //83  //0B

  jdt1800_WriteByte(0x11, 0); // SLPOUT
  itmr_Delay(150);

  jdt1800_WriteByte(0x29, 0);    // display on
  itmr_Delay(150);

  jdt1800_WriteByte(0x2D, 0);  //Look up table
  for(i = 0; i < 32; i++)
    jdt1800_WriteByte(2 * i, 1); //Red
  for(i=0; i < 64; i++)
    jdt1800_WriteByte(1 * i, 1); //Green
  for(i = 0; i < 32; i++)
    jdt1800_WriteByte(2 * i, 1); //Blue
	
  jdt1800_WriteByte(0x2c, 0);
	itmr_Delay(150);	

	jdt1800_Area(0, 0, COL_SIZE, ROW_SIZE);	
	jdt1800_SetSingleColor(BLACK);		
}	

static void jdt1800_WriteDataWord(unsigned short word)
{
  jdt1800_WriteByte((char)(word >> 8), 1);
  jdt1800_WriteByte((char)(word & 0xFF), 1);
}

static void jdt1800_SetColor(unsigned short color)
{
	jdt1800_WriteDataWord(color);
}

static void jdt1800_SetSingleColor(unsigned int color)
{
  unsigned char col, row;
  for (col = 0; col < COL_SIZE; col++)
    for (row = 0; row < ROW_SIZE; row++)
      jdt1800_SetColor(color);
}

static void jdt1800_Area(unsigned char x0, unsigned char y0, unsigned char x1, unsigned char y1)
{
  jdt1800_WriteByte(0x2a, 0);
  jdt1800_WriteByte(0, 1);
  jdt1800_WriteByte(y0, 1);
  jdt1800_WriteByte(0, 1);
  jdt1800_WriteByte(y1, 1);
  jdt1800_WriteByte(0x2b, 0);
  jdt1800_WriteByte(0, 1);
  jdt1800_WriteByte(x0, 1);
  jdt1800_WriteByte(0, 1);
  jdt1800_WriteByte(x1, 1);
  jdt1800_WriteByte(0x2c, 0);
}

void jdt1800_Point(unsigned char x, unsigned char y, unsigned int color)
{
  jdt1800_Area((COL_SIZE - x), y, (COL_SIZE - x), y);
  jdt1800_SetColor(color);
}

void jdt1800_PrintByte(unsigned char x, unsigned char y, unsigned char byte, unsigned int color)
{
	unsigned char i;
	for(i = 0; i < 8; i++){
		jdt1800_Area((x), ROW_SIZE - (y + i) - 2 * 11, (x), ROW_SIZE - (y + i) - 2 * 11);
		if((byte >> (7 - i)) & 0x01)
			jdt1800_SetColor(color);
	}
}

void jdt1800_PrintLargeChar(unsigned char x0, unsigned char y0, unsigned char ch, unsigned short color)
{
	unsigned char x, y, c;
  jdt1800_Area(x0 * 8, (11 - (y0+1)) * 11, x0 * 8 + 7, (11 - (y0+1)) * 11 + 10);	
  for(y = 0; y < 8; y++)
		for(x = 0; x < 11; x++){
			if(ch >= 192) c = 65;
			else c = 0;
			if((jdt1800font_large[ch - 32 - c][10 - x] & (1 << (7 - y))) != 0) jdt1800_SetColor(color);
			else jdt1800_SetColor(BLACK);
		}
}

void jdt1800_PrintLargeString(unsigned char x0, unsigned char y0, unsigned char* str, unsigned int color)
{
  int x, y, xx, c;	
	
	xx = /*19 - */x0;
	
	while(*str != 0){	
		jdt1800_Area(xx * 8, (11 - (y0+1)) * 11, xx * 8 + 7, (11 - (y0+1)) * 11 + 10);
    for(y = 0; y < 8; y++){
			for(x = 0; x < 11; x++){
				if(*str >= 192) c = 65;
				else c = 0;
				if(jdt1800font_large[*str - 32 - c][10 - x] & (1 << (7 - y)))
					jdt1800_SetColor(color);
				else
					jdt1800_SetColor(BLACK);		
			}		
		}
		xx++;
		str++;
	}     		
}

void jdt1800_PrintLargeBuf(	unsigned char x0, unsigned char y0, 
														unsigned char* buf, unsigned int buf_size, 
														unsigned int color)
{
  int x, y, xx, c, ind;	
	
	xx = x0;	
	
	for(ind = 0; ind < buf_size; ind++, xx++){		
		jdt1800_Area(xx * 8, (11 - (y0+1)) * 11, xx * 8 + 7, (11 - (y0+1)) * 11 + 10);
    for(y = 0; y < 8; y++){
			for(x = 0; x < 11; x++){
				if(buf[ind] >= 192) c = 65;
				else c = 0;
				if(jdt1800font_large[buf[ind] - 32 - c][10 - x] & (1 << (7 - y)))
					jdt1800_SetColor(color);
				else
					jdt1800_SetColor(BLACK);		
			}		
		}			
	}     		
}

void jdt1800_ClearRegion(unsigned char x, unsigned char y, unsigned char xc, unsigned char yc)
{
	jdt1800_Area(x * 8, (y + 1) * 11, (x + xc) * 8, (y + 1 + yc) * 11);	
	jdt1800_SetSingleColor(BLACK);
}

void jdt1800_ClearFull(void){
	jdt1800_ClearRegion(0, 0, COL_SIZE / LARGE_FONT_COL, ROW_SIZE / LARGE_FONT_ROW);
}


#endif
