#include "MDR32F9Qx_port.h"
#include "MDR32F9Qx_rst_clk.h"
#include "MDR32F9Qx_bkp.h"

#include <stdio.h>
#include "error.h"
#include "itmr.h"
#include "rtc.h"
#include "led.h"
#include "uart.h"

//#define __RTC_DEBUG__

#ifdef __RTC_DEBUG__

	#include "disp.h"
#endif

//#define COUNT_VALUE 		0 
//#define PRESC_VALUE_LS	32000


#define RTC_LSI_CLK

#define COUNT_VALUE		0
#define ALARM_VALUE		60
#define PRESC_VALUE_HS	(8192000/8)
#define PRESC_VALUE_LS	32000
#define RTCHS_PRESC		RST_CLK_HSIclkDIV8
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/


TTime Time;
#define HOUR_IN_SEC 3600
#define MIN_IN_SEC  60
#define MSEC_IN_SEC 1000
#define DAY_IN_SEC  86400ul

#ifdef __RTC_DEBUG__
unsigned int stime;
#endif

static unsigned char sec = 0;

static unsigned int time_HMS2Sec(void)
{
  return Time.hour * HOUR_IN_SEC + Time.min * MIN_IN_SEC + Time.sec;	
}

static void SetRTC( unsigned short year,
										unsigned short month,
										unsigned short date,
										unsigned short hour,
										unsigned short min,
										unsigned short sec,
										unsigned short msec)
{		
    Time.year   = year;
    Time.month  = month;
    Time.date   = date;
		Time.hour		= hour;
		Time.min 		= min;
		Time.sec 		= sec;  
		Time.msec 	= 0;
    MDR_BKP->REG_03 = Time.year;
		MDR_BKP->REG_04 = Time.month;
		MDR_BKP->REG_05 = Time.date;						       
		BKP_RTC_WaitForUpdate();
    BKP_RTC_SetCounter(time_HMS2Sec());    
		BKP_RTC_WaitForUpdate();	
}

static void rtc_Adjust(void)
{   
	unsigned int br1, br2;

	BKP_RTC_WaitForUpdate();	
	br1 = MDR_BKP->REG_01;
	br2 = MDR_BKP->REG_02;	
	
	if(((br1 & 0xFFFF) != 0x555A) || ((br2 & 0xFFFF) != 0x4545)){  				
		BKP_RTC_Reset(DISABLE);		
		MDR_BKP->REG_01 = 0x555A;
		MDR_BKP->REG_02 = 0x4545;		
    BKP_RTC_WaitForUpdate();		    
		SetRTC( START_YEAR,
						START_MONTH,
						START_DATA,
						START_HOUR,
						START_MIN,
						START_SEC,
						0 );
/*
		BKP_RTC_Reset(DISABLE);		
		MDR_BKP->REG_01 = 0x555A;
		MDR_BKP->REG_02 = 0x4545;		
    BKP_RTC_WaitForUpdate();		    
    Time.year   = START_YEAR;
    Time.month  = START_MONTH;
    Time.date   = START_DATA;
		Time.hour		= START_HOUR;
		Time.min 		= START_MIN;
		Time.sec 		= START_SEC;    
    MDR_BKP->REG_03 = Time.year;
		MDR_BKP->REG_04 = Time.month;
		MDR_BKP->REG_05 = Time.date;						       
		BKP_RTC_WaitForUpdate();
    BKP_RTC_SetCounter(time_HMS2Sec());    
		BKP_RTC_WaitForUpdate();	
*/		
  }
  else{
    Time.year   = MDR_BKP->REG_03;    
    Time.month  = MDR_BKP->REG_04; 
    Time.date   = MDR_BKP->REG_05;     		
  } 	
}

void rtc_Init(void)
{
	unsigned int stime = itmr_GetTick();
//	PORT_InitTypeDef PORT_InitStructure;

	/*
	RST_CLK_PCLKcmd(RST_CLK_PCLK_BKP,ENABLE); 	
	RST_CLK_LSEconfig(RST_CLK_LSE_ON);  	
	
	while (RST_CLK_LSEstatus() != SUCCESS){		
		if(itmr_IsTime(stime, 5000ul)){
			error_SetError(LSE_ERROR);
			break;
		}
	}	
  
	BKP_RTCclkSource(BKP_RTC_LSEclk);	
	BKP_RTC_WaitForUpdate();		
	BKP_RTC_SetPrescaler(PRESC_VALUE_LS); 	
	BKP_RTC_WaitForUpdate();  
	BKP_RTC_Enable(ENABLE);		
	rtc_Adjust();	
#ifdef __RTC_DEBUG__	
	stime = itmr_GetTick();
#endif
*/
  /* Enables the HSI clock on PORTD */
  RST_CLK_PCLKcmd(RST_CLK_PCLK_PORTB, ENABLE);

  /* Enables the HSI clock for BKP control */
  RST_CLK_PCLKcmd(RST_CLK_PCLK_BKP,ENABLE);

  /* RTC reset */
  BKP_RTC_Reset(ENABLE);
  BKP_RTC_Reset(DISABLE);


#ifdef RTC_HSI_CLK
  /* Configure RTCHSI as RTC clock source */
  RST_CLK_HSIadjust(25);
  RST_CLK_RTC_HSIclkEnable(ENABLE);
  RST_CLK_HSIclkPrescaler(RTCHS_PRESC);
  BKP_RTCclkSource(BKP_RTC_HSIclk);
#endif
#ifdef RTC_HSE_CLK
  /* Configure RTCHSE as RTC clock source */
  RST_CLK_HSEconfig(RST_CLK_HSE_ON);
  while (RST_CLK_HSEstatus()!=SUCCESS);
  RST_CLK_RTC_HSEclkEnable(ENABLE);
  BKP_RTCclkSource(BKP_RTC_HSEclk);
#endif
#ifdef RTC_LSI_CLK
  /* Configure LSI as RTC clock source */
  RST_CLK_LSIadjust(12);
  BKP_RTCclkSource(BKP_RTC_LSIclk);
  while (RST_CLK_LSIstatus()!=SUCCESS);
#endif
#ifdef RTC_LSE_CLK
  /* Configure LSE as RTC clock source */
  RST_CLK_LSEconfig(RST_CLK_LSE_ON);
  while (RST_CLK_LSEstatus()!=SUCCESS);
  BKP_RTCclkSource(BKP_RTC_LSEclk);
#endif

  /* Set the RTC prescaler value */
  BKP_RTC_WaitForUpdate();
#ifdef RTC_HSI_CLK
  BKP_RTC_SetPrescaler(PRESC_VALUE_HS);
#endif
#ifdef RTC_HSE_CLK
  BKP_RTC_SetPrescaler(PRESC_VALUE_HS);
#endif
#ifdef RTC_LSI_CLK
  BKP_RTC_SetPrescaler(PRESC_VALUE_LS);
#endif
#ifdef RTC_LSE_CLK
  BKP_RTC_SetPrescaler(PRESC_VALUE_LS);
#endif

  /* Set the RTC counter value */
  BKP_RTC_WaitForUpdate();
  BKP_RTC_SetCounter(COUNT_VALUE);

  /* Enable all RTC interrupts */
 // BKP_RTC_ITConfig(BKP_RTC_IT_ALRF | BKP_RTC_IT_SECF | BKP_RTC_IT_OWF,ENABLE);
 // NVIC_EnableIRQ(BACKUP_IRQn);


  /* Set the RTC alarm value */
  BKP_RTC_WaitForUpdate();
  BKP_RTC_SetAlarm(ALARM_VALUE);

  /* RTC enable */
  BKP_RTC_WaitForUpdate();
  BKP_RTC_Enable(ENABLE);
  rtc_Adjust();

}

TTime rtc_GetTime(void)
{	
	unsigned int counter;
	#ifdef __RTC_DEBUG__	
	char time[25];	
	#endif	
	
	if(!(error_Is() & (LSE_ERROR | RTC_WAIT1_ERROR | RTC_WAIT2_ERROR))){
		counter = BKP_RTC_GetCounter();			
	
		while(counter >= DAY_IN_SEC){
			counter -= DAY_IN_SEC;
			BKP_RTC_SetCounter(counter);  
			BKP_RTC_WaitForUpdate();
    
			Time.date++; 
    
			switch(Time.month){      
				case 1: case 3: case 5: case 7: case 8: case 10: case 12:
					if(Time.date > 31){
						Time.date = 1; Time.month++;
						if(Time.month > 12){
							Time.month = 1;
							Time.year++;
						}
					}
					break;      
				case 2:
					if(!(Time.year % 4)){
						if(Time.date > 29){
							Time.date = 1;   
							Time.month++;
						}
					}
					else{
						if(Time.date > 28){
							Time.date = 1;
							Time.month++;
						}
					}
					break;      
				case 4: case 6: case 9: case 11:
					if(Time.date > 30){
						Time.date = 1;
						Time.month++;
					}
					break;              
			}        
			MDR_BKP->REG_03 = Time.year;
			MDR_BKP->REG_04 = Time.month;
			MDR_BKP->REG_05 = Time.date;
			BKP_RTC_WaitForUpdate();
		}
  }
	else{		
		Time.year = 2000;
		Time.month = 0;
		Time.date = 0;		
		counter = 0;
	}
  Time.hour = counter / HOUR_IN_SEC; 
  Time.min = (counter % HOUR_IN_SEC) / MIN_IN_SEC;
  Time.sec = (counter % HOUR_IN_SEC) % MIN_IN_SEC;
  Time.msec = Time.sec * MSEC_IN_SEC;        
		
	return Time;
}

void rtc_Work(void)
{
	TTime time;
	char buffer[32];
	
	
	time = rtc_GetTime();
	
	if(time.sec > sec){
	sec = time.sec;
	sprintf(buffer, "%d.%d.%d %d:%d:%d \r\n> ", time.year, time.month, time.date, time.hour, time.min, time.sec);
		uart_SendBuf(buffer,23);
		
	}
	else if (time.sec < sec) { sec = 0; }
}

unsigned char rtc_GetDayInMonth(unsigned char month)
{
	switch(month){      
      case 1: case 3: case 5: case 7: case 8: case 10: case 12:	
				return 31;
			case 2:
        if(!(Time.year % 4)) return 29;        
        else return 28;
			case 4: case 6: case 9: case 11:
				return 30;
			default:
				return 30;
	}
}

void rtc_TimeSet(TTime* ptime)
{
		if(!(error_Is() & (LSE_ERROR | RTC_WAIT1_ERROR | RTC_WAIT2_ERROR)))
			SetRTC( ptime->year,
							ptime->month,
							ptime->date,
							ptime->hour,
							ptime->min,
							ptime->sec,
							0 );	
}
